@@ -86,6 +86,25 @@ agenda: |
   * Top bugs this week
 """
 
+ALTERNATING_CHAIRS_MEETING = """
+project: OpenStack Subteam Meeting
+schedule:
+  - time: '1200'
+    day: Wednesday
+    irc: openstack-meeting
+    frequency: biweekly-even
+    chair: Jane Developer
+  - time: '2200'
+    day: Wednesday
+    irc: openstack-meeting
+    frequency: biweekly-odd
+    chair: John Developer
+description: >
+    Weekly meeting for Subteam project.
+agenda: |
+  * Top bugs this week
+"""
+
 BIWEEKLY_EVEN_MEETING = """
 project: OpenStack Subteam 12 Meeting
 schedule:
@@ -447,6 +466,48 @@ description:  >
   Example Monthly meeting
 """
 
+SECOND_WEDNESDAY_MEETING = """
+project: CentOS Cloud SIG
+agenda_url: http://agenda.com/
+project_url: http://project.com
+schedule:
+  - time: '2200'
+    day: Wednesday
+    irc: centos-meeting
+    frequency: second-wednesday
+chair: Jane Deer
+description:  >
+  Example Monthly meeting
+"""
+
+SECOND_THURSDAY_MEETING = """
+project: CentOS Storage SIG
+agenda_url: http://agenda.com/
+project_url: http://project.com
+schedule:
+  - time: '2200'
+    day: Thursday
+    irc: centos-meeting
+    frequency: second-thursday
+chair: Jane Deer
+description:  >
+  Example Monthly meeting
+"""
+
+SECOND_FRIDAY_MEETING = """
+project: CentOS Hyperscale SIG
+agenda_url: http://agenda.com/
+project_url: http://project.com
+schedule:
+  - time: '2200'
+    day: Friday
+    irc: centos-meeting
+    frequency: second-friday
+chair: Jane Deer
+description:  >
+  Example Monthly meeting
+"""
+
 THIRD_MONDAY_MEETING = """
 project: OpenStack Random Meeting
 agenda_url: http://agenda.com/
@@ -516,3 +577,73 @@ chair: John Doe
 description:  >
   Example Monthly meeting
 """
+
+FOURTH_MONDAY_MEETING = """
+project: CentOS SIG Meeting
+agenda_url: http://agenda.com/
+project_url: http://project.com
+schedule:
+  - time: '2200'
+    day: Monday
+    irc: centos-meeting
+    frequency: fourth-monday
+chair: Jane Deer
+description:  >
+  Example Monthly meeting
+"""
+
+FOURTH_TUESDAY_MEETING = """
+project: CentOS SIG Meeting
+agenda_url: http://agenda.com/
+project_url: http://project.com
+schedule:
+  - time: '2200'
+    day: Tuesday
+    irc: centos-meeting
+    frequency: fourth-tuesday
+chair: Jane Deer
+description:  >
+  Example Monthly meeting
+"""
+
+FOURTH_WEDNESDAY_MEETING = """
+project: CentOS SIG Meeting
+agenda_url: http://agenda.com/
+project_url: http://project.com
+schedule:
+  - time: '2200'
+    day: Wednesday
+    irc: centos-meeting
+    frequency: fourth-wednesday
+chair: Jane Deer
+description:  >
+  Example Monthly meeting
+"""
+
+FOURTH_THURSDAY_MEETING = """
+project: CentOS SIG Meeting
+agenda_url: http://agenda.com/
+project_url: http://project.com
+schedule:
+  - time: '2200'
+    day: Thursday
+    irc: centos-meeting
+    frequency: fourth-thursday
+chair: Jane Deer
+description:  >
+  Example Monthly meeting
+"""
+
+FOURTH_FRIDAY_MEETING = """
+project: CentOS SIG Meeting
+agenda_url: http://agenda.com/
+project_url: http://project.com
+schedule:
+  - time: '2200'
+    day: Friday
+    irc: centos-meeting
+    frequency: fourth-friday
+chair: Jane Deer
+description:  >
+  Example Monthly meeting
+"""
